package common

import (
	"errors"
	"regexp"
	"strconv"
	"strings"
)

type ID string // collectionIndex||SplitFlag||token

func GetCollectionIndexFromID(id ID) (string, error) {
	splits := strings.Split(string(id), SplitFlag)
	if len(splits) != 2 {
		return "", errors.New("ID is invalid")
	}
	if isMatch, err := regexp.MatchString(CollectionIndexRegx, splits[0]); !isMatch || err != nil {
		return "", errors.New("collection index invalid, length should in [3,32]")
	}
	return splits[0], nil
}

func GetTokenIdFromID(id ID) (TokenID, error) {
	splits := strings.Split(string(id), SplitFlag)
	if len(splits) != 2 {
		return InvalidTokenID, errors.New("ID is invalid")
	}
	tokenID, err := ConvTokenStr(splits[1])
	if err != nil {
		return InvalidTokenID, err
	}
	return tokenID, nil
}

func GetCollectionIndexsFromIDs(ids []ID) ([]string, error) {
	collectionIndexs := make([]string, len(ids))
	for i, id := range ids {
		splits := strings.Split(string(id), SplitFlag)
		if len(splits) != 2 {
			return collectionIndexs, errors.New(string(id) + "ID is invalid")
		}
		if isMatch, err := regexp.MatchString(CollectionIndexRegx, splits[0]); !isMatch || err != nil {
			return collectionIndexs, errors.New(strconv.Itoa(i) + ": collection index invalid, length should in [3,32]")
		}
		collectionIndexs[i] = splits[0]
	}
	return collectionIndexs, nil
}
